# GENERATED FILE - DO NOT EDIT
VERSION = '201801101335'
BUILDS = {'Darwin': {'sha256': '12dbbfac8c8b97aebfa33b053201bc614988d775011fdd0b16ecbc2acf4cf53b',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201801101335-OSXIntel64.zip'},
 'Docker': {'tag': '201801101335'},
 'Linux': {'sha256': '128c0bcf3a62991d40092cf5f874fe946811308aaaa82f91ebbf40ccdf83645b',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201801101335-Linux64.zip'}}